@@ -272,7 +272,6 @@ OC.L10N.register(
     "Mute audio" : "Спиране на звука",
     "Disable video" : "Изключване на видеото",
     "Enable video" : "Включи видео",
-    "Back" : "Назад",
     "You" : "Ти",
     "Favorite" : "Любима",
     "Remove from favorites" : "Премахни от любимите",
@@ -282,6 +281,7 @@ OC.L10N.register(
     "Circles" : "Обкръжения",
     "Settings" : "Настройки",
     "Password protect" : "Защита с парола",
+    "Back" : "Назад",
     "Close" : "Затваряне",
     "Camera" : "Камера",
     "Reply" : "Отговори",
@@ -310,6 +310,7 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Enter a password" : "Въведете парола",
     "Grid view" : "Решетъчен изглед",
+    "Send" : "Изпрати",
     "Default" : "Стандартен",
     "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
     "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
@@ -320,25 +321,11 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
     "Android app" : "Android приложение",
     "iOS app" : "iOS приложениер",
-    "Copy" : "Копиране",
-    "Copied!" : "Копирано!",
-    "Not supported!" : "Не се поддържа!",
-    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
-    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
-    "Password required" : "Паролата е задължителна",
-    "Cancel" : "Отказ",
-    "Submit" : "Изпращане",
+    "Contacts" : "Контакти",
     "Guests" : "Гости",
     "Webinar" : "Уебинар",
-    "Change password" : "Промени паролата",
-    "Set password" : "Задайте парола",
-    "Rename" : "Преименуване",
-    "Link copied!" : "Връзката е копирана!",
-    "Send" : "Изпрати",
-    "Share" : "Споделяне",
-    "Error while sharing" : "Грешка при споделяне",
-    "Share screen" : "Споделяне на екран",
-    "Favorited" : "Отбелязано в любими",
-    "Contacts" : "Контакти"
+    "Password required" : "Паролата е задължителна",
+    "Cancel" : "Отказ",
+    "Submit" : "Изпращане"
 },
 "nplurals=2; plural=(n != 1);");
