@@ -566,14 +566,6 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro. Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
     "Screensharing options" : "Dibaboù rannañ skramm",
     "Enable screensharing" : "Aotreañ ar rannan skramm",
-    "Back" : "Distro",
-    "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
-    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
-    "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
     "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
     "Bad sent screen quality." : "Fall eo perzh ar skramm.",
     "Bad sent video quality." : "Fall eo perzh ar gasadenn ar video.",
@@ -589,6 +581,13 @@ OC.L10N.register(
     "Disable screenshare" : "Rannañ skramm disaotreet",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hll ket marteze ar re all komprenn ac'hanaoc'h. La'hit ar video evit gwelaat an traoù.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ho kenstagadenn onternet pe ho urzhiataer a labour ha marteze ne c'hell ket ar re all komprenn ac'hanoc'h.",
+    "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
+    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
+    "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
     "Error while accessing camera" : "Ur fazi a zo bet en ur tizhout ar c'hamera",
     "You have been muted by a moderator" : "Mut oc'h bet lakaet gant ar moderatour",
     "You" : "C'hwi",
@@ -596,7 +595,6 @@ OC.L10N.register(
     "Mute" : "Mut",
     "Stop following" : "Arrest heuliañ",
     "You need to be logged in to upload files" : "Ret eo deoc'h bezhañ deuet-tre evit pellkas restroù",
-    "This conversation is read only" : "An diviz a zo da lenn-nemetken",
     "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
     "Call in progress" : "Kemenadenn en dro",
     "Favorite" : "Pennroll",
@@ -630,6 +628,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
     "Password protect" : "Ger-tremen gwarezet",
     "Add participants" : "Ouzhpennan tud",
+    "Back" : "Distro",
     "Create conversation" : "Krouiñ un diviz",
     "Close" : "Serriñ",
     "Choose a password" : "Choaz ur get-trmenn",
@@ -658,13 +657,13 @@ OC.L10N.register(
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
     "Share files to the conversation" : "Rannañ restroù d'an diviz",
     "Upload new files" : "Pelkas ur restr nevez",
     "Share from Files" : "Rannañ diouzh Restroù",
     "Add emoji" : "Ouzhpennañ un emoji",
     "Send message" : "Kas ur gemenadenn",
     "File to share" : "Restr da rannañ",
+    "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
     "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Enabled" : "Aotreet",
     "Save" : "Enrollañ",
@@ -689,7 +688,6 @@ OC.L10N.register(
     "Add users or circles" : "Ouhzpennañ implijourienn pe kelc'hioù",
     "Add groups or circles" : "Ouhzpennañ strolladoù pe kelc'hioù",
     "Add other sources" : "Ouzhpennañ dre un orin all",
-    "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
     "Participants" : "Tud",
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Chat" : "Chat",
@@ -715,6 +713,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Kuitaat ar skramm a bez (f)",
     "Fullscreen (f)" : "Skramm a bez (f)",
     "Grid view" : "Diskwell ar roued",
+    "Send" : "Kas",
     "Add more files" : "Ouzhpennañ muioc'h a restroù",
     "No unread mentions" : "Kemenadenn nan-lennet ebet",
     "Say hi to your friends and colleagues!" : "Lâr koukouk d'ho mignoned ha genseurted",
@@ -770,75 +769,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
     "Android app" : "Meziant Android",
     "iOS app" : "Meziant iOS",
-    "Enter name for a new conversation" : "Lakait ho anv evit an diviz",
-    "{name} (public)" : "{name} (publik)",
-    "New conversation …" : "Diviz nevez ...",
-    "Projects" : "Raktres",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Kemennadennoù gant muioc'h eget 4 implijer hep servijour arhent diavaez a c'hell kaout kudennoù kenstagañ ha lakaat kargadennoù bras war ardivinkoù an implijourienn.",
-    "Copy" : "Eilañ",
-    "Copied!" : "Eilet eo !",
-    "Not supported!" : "Diembreget eo ! ",
-    "Press ⌘-C to copy." : "Pouezañ war ⌘-C evit eilañ. ",
-    "Press Ctrl-C to copy." : "Pouezañ war Ctrl-C evit eilañ. ",
-    "Error while getting the room ID" : "Ur fazi a zo bet en ur tapout ID ar sal",
-    "Room name can not be empty" : "An anv sal na c'hell ket bezhañ goulo",
-    "Please enter the password for this call" : "Lakit ur ger-temenn evit ar gemenadenn-mañ",
-    "Password required" : "Ger-tremen ret",
-    "Cancel" : "Arrest",
-    "Submit" : "Kinnig",
-    "Calls are disabled in this conversation." : "N'eo ket aotreaet ar gemenadennoù en diviz.",
-    "Guests" : "Kouviidi",
-    "Webinar" : "Bebinar",
-    "Only moderators can enter the conversation when the lobby is enabled" : "N'ez eus nemet ar modaratourienn a c'hell mont en diviz pa ez eo aotreet ar sal gortoz",
-    "Change password" : "Cheñch ger-tremen",
-    "Set password" : "Termeniñ ur ger-tremen",
-    "Error occurred while renaming the conversation" : "Ur fazi a zo bet en ur adenvel an diviz",
-    "Rename" : "Adenvel",
-    "Link copied!" : "Liamm eilet !",
-    "Conversation with {name}" : "Diviz gant {name}",
-    "Error occurred while making the conversation public" : "Ur fazi a zo bet en ur lakaat an diviz da bublik",
-    "Error occurred while making the conversation private" : "Ur fazi a zo bet en ur lakaat an diviz da brevez",
-    "Error occurred while setting password" : "C'hoarvezet ez eus ur fazi en ur dermeniñ ar ger-tremen",
-    "Error occurred while changing lobby state" : "Ur fazi a zoo bet en ur cheñch stad ar zal gortoz",
-    "Invalid start time format" : "Stumm amzer kregiñ fal",
-    "Error occurred while setting the lobby start time" : "Ur fazi a zo bet en ur staliañ amzer kregiñ ar zal gortoz",
-    "No messages yet, start the conversation!" : "Kemenadenn ebet evit ar poent, krogit un diviz !",
-    "New message …" : "Kemenadenn nevez ...",
-    "Send" : "Kas",
-    "You can not send messages, because the conversation is locked." : "Ne c'heller ket kas ur gemenadenn, abalamour ma ez eo prennet an diviz.",
-    "The conversation is locked." : "Prennet eo an diviz.",
-    "Share" : "Rannan",
-    "[Unknown user name]" : "[Anv implijer dianv]",
-    "The message you are trying to send is too long" : "Ar gemenadenn emaoc'h ho klask kas a zo re vras",
-    "Error occurred while sending message" : "Ur fazi a zo bet en ur kas ar gemenadenn",
-    "Error while sharing" : "Ur fazi oa e pad ar rannañ",
     "No other people in this call" : "Denn ebet all er gemenadenn",
-    "Waiting for {participantName} to join the call …" : "O c'hortoz e vefe {participantName} er gemenadenn",
-    "WebRTC is not supported in your browser :-/" : "BavRTC n'eo ket douget en ho furcher :-/",
-    "Waiting for camera and microphone permissions" : "Ho gortoz an aotreoù evit ho mikro ha kamera",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Aotreitd'ho furcher tizhout ho kamera ha mikro evit implij ar meziant.",
-    "Set your name in the chat window so other participants can identify you better." : "Lakait ho anv e prenestr ar chat evit bezhañ anavezet aesoc'h gant an implijourienn all.",
-    "Share screen" : "Rannañ ar skramm",
-    "No Camera" : "Kamera ebet",
-    "Screensharing is not supported by your browser." : "Ar rannañ-skramm n'eo ket douger gant ho furcher.",
-    "Error while promoting user to moderator" : "Ur fazi a zo bet pa oa lakaet un implijer da moderatour",
-    "Error while demoting moderator" : "Ur fazi a zo bet en ur lemel an droet moderatour",
-    "Error while removing user from room" : "Ur fazi a zo bet en ul lemel an implijer eus ar sal",
-    "Add participant …" : "Ouzhpennañ tud ...",
-    "Favorited" : "Lakaet evel pennroll",
     "Your screen" : "Ho skramm",
-    "{participantName}'s screen" : "Skramm {participantName}",
-    "Guest's screen" : "Skramm ar c'houviat",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : " 99% match \n- Ur sal gortoz eo posupl kaout evit an divizoù. Aotreañ a raio an habaskaerien da vont er chat hag er gemenaden evit prientiñ ar gejadenn, padal eo ret d'an implijourien ha d'ar gouviidi gortoz",
-    "{email} tried to requested the password to access {file}" : "{email} en/he deus klasket goulenn ar ger-tremen evit tizhout {file}",
-    "Someone tried to requested the password to access {file}" : "Unan bennak en deus klasket goulenn ar ger-tremen evit tizhout {file}",
-    "Limit app usage to groups." : "Bevenna implij ar meziant da strolladoù.",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon <a {attributes}>diellvadur ↗</a>.",
-    "Start calls" : "Kregiñ ur gemenadenn",
-    "Who can start a call?" : "Piv a c'hell kregiñ ur gemenadenn ?",
-    "Select a conversation to add to the project" : "Choaz un diviz da ouzhpennañ er raktres",
-    "A TURN server is used to proxy the traffic from participants behind a firewall." : "Ur servijer TURN a zo implijet evit proksiañ froud an implijaderien a-drek ur voger-dan.",
-    "Join conversations at any time, any where, on any device." : "Kit er gemenadenn n'euz forzh peseurt amzer, lec'h pe ardivink.",
     "Contacts" : "Darempredoù",
     "Contacts, groups and circles" : "Darempredoùn, strolladoù ha kelc'hioù",
     "Contacts and groups" : "Darempredoù ha strolladoù",
@@ -846,17 +778,29 @@ OC.L10N.register(
     "Loading contacts" : "HO kargañ an darempredoù",
     "Select participants" : "Choaz unan bennak",
     "Search conversations or contacts" : "Klask un diviz pe un darempred",
+    "[Unknown user name]" : "[Anv implijer dianv]",
     "Search for more contacts" : "Klask muioc'h ha darempredoù",
     "Contacts loading" : "Darempredoù o kargañ",
+    "Add participants to the conversation" : "Ouzhpennañ tud en diviz",
     "Add contacts" : "Ouzhpennañ darempredoù",
     "Add contacts, groups or circles" : "Ouzhpennañ darempredoù, strolladoù pe kelc'hioù",
     "Add contacts or groups" : "Ouzphennañ darempredoù pe strolladoù",
     "Add contacts or circles" : "Ouzhpennañ darempredoù pe kelc'hioù",
+    "Guests" : "Kouviidi",
+    "Webinar" : "Bebinar",
+    "Projects" : "Raktres",
+    "Limit app usage to groups." : "Bevenna implij ar meziant da strolladoù.",
+    "Start calls" : "Kregiñ ur gemenadenn",
+    "Who can start a call?" : "Piv a c'hell kregiñ ur gemenadenn ?",
+    "Select a conversation to add to the project" : "Choaz un diviz da ouzhpennañ er raktres",
+    "Please enter the password for this call" : "Lakit ur ger-temenn evit ar gemenadenn-mañ",
+    "Password required" : "Ger-tremen ret",
+    "Cancel" : "Arrest",
+    "Submit" : "Kinnig",
     "Signaling server URL" : "O arhentañ URL ar servijour",
+    "This conversation is read only" : "An diviz a zo da lenn-nemetken",
     "Default location for attachments" : "Lec'h dre ziouer evit ar stagadennoù",
     "Select default location for attachments" : "Choaz al lec'h stagadenn dre ziouer",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk a zo bet adnevesaet, ret eo deoc'h freskaat ar bajenn a raok kregin pe mont en ur gemenadenn",
-    "Use promoted view" : "Implij ar gwellet herouezet",
-    "Promoted view" : "Gwellet herouezet"
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk a zo bet adnevesaet, ret eo deoc'h freskaat ar bajenn a raok kregin pe mont en ur gemenadenn"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
