@@ -310,7 +310,6 @@ OC.L10N.register(
     "Enable video" : "Slå video til",
     "Screensharing options" : "Skærmdeling indstillinger",
     "Enable screensharing" : "Slå skærmdeling til",
-    "Back" : "Tilbage",
     "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
@@ -323,7 +322,6 @@ OC.L10N.register(
     "Show screen" : "Vis skærm",
     "Mute" : "Mute",
     "You need to be logged in to upload files" : "Du skal være logget ind for at kunne uploade filer",
-    "This conversation is read only" : "Denne samtale er skrivebeskyttet",
     "Drop your files to upload" : "Drop dine filer for at uploade",
     "Call in progress" : "Opkald i gang",
     "Favorite" : "Foretrukken",
@@ -352,6 +350,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Opret en ny gruppesamtale",
     "Password protect" : "Beskyt med adgangskode",
     "Add participants" : "Tilføj deltagere",
+    "Back" : "Tilbage",
     "Create conversation" : "Opret samtale",
     "Close" : "Luk",
     "Choose a password" : "Vælg en adgangskode",
@@ -368,11 +367,11 @@ OC.L10N.register(
     "Today" : "I dag",
     "Yesterday" : "I går",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
     "Upload new files" : "Upload nye filer",
     "Share from Files" : "Del fra Filer",
     "Send message" : "Send besked",
     "File to share" : "Vælg fil til deling",
+    "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
     "Invalid path selected" : "Ugyldig filsti valgt",
     "Enabled" : "Aktiveret",
     "Save" : "Gem",
@@ -394,7 +393,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "Tilføj grupper eller cirkler",
     "Add other sources" : "Tilføj andre kilder",
-    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
     "Participants" : "Deltagere",
     "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Chat" : "Chat",
@@ -414,6 +412,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
     "Fullscreen (f)" : "Vis i fuldskærm (f)",
     "Grid view" : "Grid visning",
+    "Send" : "Send",
     "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
     "Start a conversation" : "Start en samtale",
     "Message without mention" : "Besked som ikke nævner nogen",
@@ -447,75 +446,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "Enter name for a new conversation" : "Indtast navn på en ny samtale",
-    "{name} (public)" : "{name} (offentlig)",
-    "New conversation …" : "Ny samtale …",
-    "Projects" : "Projekter",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
-    "Copy" : "Kopiér",
-    "Copied!" : "Kopieret!",
-    "Not supported!" : "Ikke understøttet",
-    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
-    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
-    "Error while getting the room ID" : "Fejl ved generering af rum-ID",
-    "Room name can not be empty" : "Navnet på rummet kan ikke stå tomt",
-    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
-    "Password required" : "Password påkrævet",
-    "Cancel" : "Annullér",
-    "Submit" : "Indsend",
-    "Calls are disabled in this conversation." : "Opkald er slået fra i denne samtale.",
-    "Guests" : "Gæster",
-    "Webinar" : "Webinar",
-    "Only moderators can enter the conversation when the lobby is enabled" : "Kun moderatorer kan gå med i samtalen når lobbyen er slået til",
-    "Change password" : "Skift password",
-    "Set password" : "Sæt password",
-    "Error occurred while renaming the conversation" : "Kunne ikke omdøbe samtalen",
-    "Rename" : "Omdøb",
-    "Link copied!" : "Link kopieret!",
-    "Conversation with {name}" : "Samtale med {name}",
-    "Error occurred while making the conversation public" : "Kunne ikke gøre samtalen offentlig",
-    "Error occurred while making the conversation private" : "Kunne ikke gøre samtalen privat",
-    "Error occurred while setting password" : "Der opstod en fejl ved indstilling af adgangskode",
-    "Error occurred while changing lobby state" : "Kunne ikke ændre lobby-tilstanden",
-    "Invalid start time format" : "Ugyldigt format for starttid",
-    "Error occurred while setting the lobby start time" : "Kunne ikke sætte lobby-starttiden",
-    "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
-    "New message …" : "Ny besked …",
-    "Send" : "Send",
-    "You can not send messages, because the conversation is locked." : "Du kan ikke sende beskeder fordi samtalen er låst.",
-    "The conversation is locked." : "Samtalen er låst.",
-    "Share" : "Del",
-    "[Unknown user name]" : "[Ukendt brugernavn] ",
-    "The message you are trying to send is too long" : "Beskeden du prøver at sende er for lang",
-    "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
-    "Error while sharing" : "Fejl under deling",
     "No other people in this call" : "Ingen andre deltager i dette opkald",
-    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
-    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
-    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
-    "Set your name in the chat window so other participants can identify you better." : "Sæt dit navn i chatvinduet, så andre deltagere bedre kan identificere dig.",
-    "Share screen" : "Del skærm",
-    "No Camera" : "Intet kamera",
-    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
-    "Error while promoting user to moderator" : "Fejl ved forfremmelse af bruger til moderator",
-    "Error while demoting moderator" : "Fejl ved degradering af moderator",
-    "Error while removing user from room" : "Fejl under fjernelse af bruger fra rummet",
-    "Add participant …" : "Tilføj deltager…",
-    "Favorited" : "Tilføjet til favoritter",
     "Your screen" : "Din skærm",
-    "{participantName}'s screen" : "{participantName}s skærm",
-    "Guest's screen" : "Gæsts skærm",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Samtaler kan nu have en lobby. Dette giver mulighed for at moderatorer kan forbinde til samtalen for at forberede mødet, mens almindelige brugere og gæster må vente",
-    "{email} tried to requested the password to access {file}" : "{email} forsøgte at anmode om adgangskoden til {file}",
-    "Someone tried to requested the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
-    "Limit app usage to groups." : "Begræns app-brug til grupper.",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandoer er en ny beta-feature i Nextcloud Talk. De tillader dig at køre scripts på din Nextcloud-server. Du kan definere dem vha vores kommandolinje-interface. Et eksempel på et lommeregner-script kan findes i vores <a {attributes}>dokumentation ↗</a>.",
-    "Start calls" : "Start opkald",
-    "Who can start a call?" : "Hvem kan starte et opkald?",
-    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
-    "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-server bruges som proxy for trafik fra deltagere som er bag en firewall.",
-    "Join conversations at any time, any where, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Contacts" : "Kontakter",
     "Contacts, groups and circles" : "Kontakter, grupper og cirkler",
     "Contacts and groups" : "Kontakter og grupper",
@@ -523,13 +455,27 @@ OC.L10N.register(
     "Loading contacts" : "Henter kontakter",
     "Select participants" : "Vælg deltagere",
     "Search conversations or contacts" : "Søg efter samtaler og kontakter",
+    "[Unknown user name]" : "[Ukendt brugernavn] ",
     "Search for more contacts" : "Søg efter flere kontakter",
     "Contacts loading" : "Henter kontakter",
+    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
     "Add contacts" : "Tilføj kontakter",
     "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
     "Add contacts or groups" : "Tilføj kontakter eller grupper",
     "Add contacts or circles" : "Tilføj kontakter eller cirkler",
+    "Guests" : "Gæster",
+    "Webinar" : "Webinar",
+    "Projects" : "Projekter",
+    "Limit app usage to groups." : "Begræns app-brug til grupper.",
+    "Start calls" : "Start opkald",
+    "Who can start a call?" : "Hvem kan starte et opkald?",
+    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
+    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
+    "Password required" : "Password påkrævet",
+    "Cancel" : "Annullér",
+    "Submit" : "Indsend",
     "Signaling server URL" : "Signalserver URL",
+    "This conversation is read only" : "Denne samtale er skrivebeskyttet",
     "Default location for attachments" : "Standard-lokation for vedhæftninger",
     "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger"
 },
