@@ -263,7 +263,6 @@ OC.L10N.register(
     "Saved" : "Konservita",
     "Copy link" : "Kopii ligilon",
     "Dismiss" : "Preterpasi",
-    "Back" : "Antaŭen",
     "You" : "Vi",
     "Favorite" : "Pliŝatata",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
@@ -273,6 +272,7 @@ OC.L10N.register(
     "Circles" : "Rondoj",
     "Settings" : "Agordoj",
     "Password protect" : "Protekti per pasvorto",
+    "Back" : "Antaŭen",
     "Close" : "Malfermi",
     "Camera" : "Fotilo",
     "Reply" : "Respondi",
@@ -297,26 +297,15 @@ OC.L10N.register(
     "Password protection" : "Protektita per pasvorto",
     "Enter a password" : "Entajpu pasvorton",
     "Grid view" : "Krada vido",
+    "Send" : "Sendi",
     "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
-    "Copy" : "Kopii",
-    "Copied!" : "Kopiita!",
-    "Not supported!" : "Ne subtenite!",
-    "Press ⌘-C to copy." : "Premu ⌘-C por kopii.",
-    "Press Ctrl-C to copy." : "Premu Ctrl-C por kopii.",
+    "Contacts" : "Kontaktoj",
+    "Guests" : "Gastoj",
     "Password required" : "Pasvorto bezonata",
     "Cancel" : "Nuligi",
-    "Submit" : "Sendi",
-    "Guests" : "Gastoj",
-    "Change password" : "Ŝanĝi la pasvorton",
-    "Set password" : "Uzi pasvorton",
-    "Rename" : "Alinomi",
-    "Send" : "Sendi",
-    "Share" : "Kunhavigi",
-    "Error while sharing" : "Eraro dum kunhavigo",
-    "Favorited" : "Pliŝatitaj",
-    "Contacts" : "Kontaktoj"
+    "Submit" : "Sendi"
 },
 "nplurals=2; plural=(n != 1);");
