@@ -37,7 +37,6 @@ OC.L10N.register(
     "Dismiss" : "Despedir",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
-    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
@@ -54,6 +53,7 @@ OC.L10N.register(
     "Circles" : "Círculos",
     "Settings" : "Ajustes",
     "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de conversación",
     "Camera" : "Cámara",
@@ -82,6 +82,7 @@ OC.L10N.register(
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingrese una contraseña",
     "Grid view" : "Vista de cuadrícula",
+    "Send" : "Enviar",
     "Start a conversation" : "Iniciar una conversación",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -94,32 +95,12 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presione ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presione Ctrl-C para copiar.",
+    "No other people in this call" : "No hay más personas en esta llamada",
+    "Your screen" : "Su pantalla",
+    "Contacts" : "Contactos",
+    "Guests" : "Invitados",
     "Password required" : "Se requiere contraseña",
     "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Guests" : "Invitados",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Configurar contraseña",
-    "Rename" : "Renombrar",
-    "Send" : "Enviar",
-    "Share" : "Compartir",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en su navegador :-/",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Favor de dar acceso a su navegador a usar su camara y micrófono poder usar esta aplicaión. ",
-    "Share screen" : "Compartir la pantalla",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por su navegador. ",
-    "Favorited" : "Marcado como favorito",
-    "Your screen" : "Su pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "Contacts" : "Contactos"
+    "Submit" : "Enviar"
 },
 "nplurals=2; plural=(n != 1);");
