@@ -145,7 +145,6 @@ OC.L10N.register(
     "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
-    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
@@ -163,6 +162,7 @@ OC.L10N.register(
     "Circles" : "Círculos",
     "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
+    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de la conversación",
     "Reply" : "Responder",
@@ -196,6 +196,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
     "Fullscreen (f)" : "Pantalla completa (f)",
     "Grid view" : "Vista de cuadrícula",
+    "Send" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
@@ -211,45 +212,14 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "New conversation …" : "Nueva conversación ...",
-    "Copy" : "Copiar",
-    "Copied!" : "¡Copiado!",
-    "Not supported!" : "¡No soportado!",
-    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
+    "No other people in this call" : "No hay más personas en esta llamada",
+    "Your screen" : "Tu pantalla",
+    "Contacts" : "Contactos",
+    "[Unknown user name]" : "[Nombre de usuario desconocido]",
+    "Guests" : "Invitados",
     "Please enter the password for this call" : "Por favor ingresa la contraseña para esta llamada",
     "Password required" : "Contraseña requerida",
     "Cancel" : "Cancelar",
-    "Submit" : "Enviar",
-    "Guests" : "Invitados",
-    "Change password" : "Cambiar contraseña",
-    "Set password" : "Establecer contraseña",
-    "Rename" : "Renombrar",
-    "Link copied!" : "¡Liga copiada!",
-    "Conversation with {name}" : "Conversación con {name}",
-    "Error occurred while setting password" : "Se presentó un error al establecer al contraseña",
-    "No messages yet, start the conversation!" : "Aún no hay mensajes. ¡!Inicia la conversación!",
-    "New message …" : "Mensaje nuevo ...",
-    "Send" : "Enviar",
-    "Share" : "Compartir",
-    "[Unknown user name]" : "[Nombre de usuario desconocido]",
-    "Error occurred while sending message" : "Se presentó un error al enviar el mensaje",
-    "Error while sharing" : "Se presentó un error al compartir",
-    "No other people in this call" : "No hay más personas en esta llamada",
-    "Waiting for {participantName} to join the call …" : "Esperando a que {participantName} se una a la llamada…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC no se encuentra soportado en tu navegador :-/",
-    "Waiting for camera and microphone permissions" : "Aguardando los permisos para la cámara y micrófono",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor da acceso a tu navegador para usar tu camara y micrófono poder usar esta aplicación. ",
-    "Share screen" : "Compartir la pantalla",
-    "No Camera" : "Sin cámara",
-    "Screensharing is not supported by your browser." : "Compartir pantalla no está soportado por tu navegador. ",
-    "Add participant …" : "Agregar participante ...",
-    "Favorited" : "Marcado como favorito",
-    "Your screen" : "Tu pantalla",
-    "{participantName}'s screen" : "Pantalla de {participantName}",
-    "Guest's screen" : "Pantalla del invitado",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Las conversaciones ahora pueden tener un lobby. Esto permitirá a moderadores preparar el char y llamadas para jutas, mientras usuarios e invitados esperan.",
-    "Join conversations at any time, any where, on any device." : "Únete a conversaciones en cualquier momento, en cualquier lugar, en cualquier dispositivo.",
-    "Contacts" : "Contactos"
+    "Submit" : "Enviar"
 },
 "nplurals=2; plural=(n != 1);");
