@@ -97,6 +97,14 @@ OC.L10N.register(
     "Open settings" : "Avaa asetukset",
     "Conversations" : "Keskustelut",
     "Messages" : "Viestit",
+    "{user}" : "{user}",
+    "Messages in {conversation}" : "Viestit keskustelussa {conversation}",
+    "{user} in {conversation}" : "{user} keskustelussa {conversation}",
+    "Something unexpected happened." : "Jotain odottamatonta tapahtui.",
+    "The email address is invalid." : "Sähköpostiosoite on virheellinen.",
+    "The language is invalid." : "Kieli on virheellinen.",
+    "The country is invalid." : "Maa on virheellinen.",
+    "Something unexpected happened. Please try again later." : "Jotain odottamatonta tapahtui. Yritä myöhemmin uudelleen.",
     "Austria" : "Itävalta",
     "Belgium" : "Belgia",
     "Bulgaria" : "Bulgaria",
@@ -147,6 +155,7 @@ OC.L10N.register(
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
     "Chat, video & audio-conferencing using WebRTC" : "Keskustelu ja video- sekä äänineuvottelut WebRTC:tä käyttäen",
     "Leave call" : "Poistu puhelusta",
+    "Stay in call" : "Pysy puhelussa",
     "Discuss this file" : "Keskustele tästä tiedostosta",
     "Share this file with others to discuss it" : "Jaa tämä tiedosto muiden kanssa keskustellaksesi siitä",
     "Share this file" : "Jaa tämä tiedosto",
@@ -172,10 +181,12 @@ OC.L10N.register(
     "General settings" : "Yleiset asetukset",
     "Default notification settings" : "Ilmoitusten oletusasetukset",
     "Default group notification" : "Ryhmän oletusilmoitus",
+    "Integration into other apps" : "Integraatio muihin sovelluksiin",
     "Allow conversations on files" : "Salli keskustelut tiedostoista",
     "All messages" : "Kaikki viestit",
     "@-mentions only" : "Vain @-maininnat",
     "Off" : "Pois",
+    "E-mail of the user" : "Käyttäjän sähköpostiosoite",
     "Language" : "Kieli",
     "Country" : "Maa",
     "Status" : "Tila",
@@ -185,8 +196,20 @@ OC.L10N.register(
     "Blocked" : "Estetty",
     "Active" : "Aktiivinen",
     "Expired" : "Vanhentunut",
+    "The account could not be deleted. Please try again later." : "Tätä tiliä ei voitu poistaa. Yritä myöhemmin uudelleen.",
+    "_%n user_::_%n users_" : ["%n käyttäjä","%n käyttäjää"],
+    "Matterbridge integration" : "Matterbridge-integraatio",
+    "Enable Matterbridge integration" : "Käytä Matterbridge-integraatiota",
+    "Downloading …" : "Ladataan…",
+    "Installed version: {version}" : "Asennettu versio: {version}",
+    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binääriä ei löytynyt tai sitä ei voitu suorittaa.",
+    "Failed to execute Matterbridge binary." : "Matterbridge-binäärin suorittaminen epäonnistui.",
     "Validate SSL certificate" : "Vahvista SSL-varmenne",
     "Delete this server" : "Poista tämä palvelin",
+    "Status: Checking connection" : "Tila: Tarkistetaan yhteyttä",
+    "OK: Running version: {version}" : "OK: Suoritetaan versiota: {version}",
+    "Error: Can not connect to server" : "Virhe: Ei voi yhdistää palvelimeen",
+    "Error: Unknown error occurred" : "Virhe: Tuntematon virhe",
     "Saved" : "Tallennettu",
     "Add a new server" : "Lisää uusi palvelin",
     "Shared secret" : "Jaettu salaisuus",
@@ -222,7 +245,6 @@ OC.L10N.register(
     "Enable video" : "Käytä videota",
     "Screensharing options" : "Näytönjakamisen valinnat",
     "Enable screensharing" : "Ota käyttöön näytönjakaminen",
-    "Back" : "Takaisin",
     "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
@@ -233,22 +255,27 @@ OC.L10N.register(
     "You" : "Sinä",
     "Show screen" : "Näytä näyttö",
     "Mute" : "Mykistä",
-    "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
+    "Stop following" : "Lopeta seuraaminen",
     "Drop your files to upload" : "Pudota tiedostot lähettääksesi ne",
     "Call in progress" : "Puhelu meneillään",
     "Favorite" : "Suosikki",
+    "Conversation settings" : "Keskustelun asetukset",
     "Chat notifications" : "Keskusteluilmoitukset",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "You: {lastMessage}" : "Sinä: {lastMessage}",
+    "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
     "No matches" : "Ei täsmääviä",
     "Loading" : "Ladataan",
     "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
     "Circles" : "Piirit",
     "Settings" : "Asetukset",
+    "Users, groups and circles" : "Käyttäjät, ryhmät ja piirit",
+    "Users and groups" : "Käyttäjät ja ryhmät",
+    "Users and circles" : "Käyttäjät ja piirit",
     "Groups and circles" : "Ryhmät ja piirit",
     "Other sources" : "Muut lähteet",
     "Creating your conversation" : "Luodaan keskustelua",
@@ -258,6 +285,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
     "Password protect" : "Suojaa salasanalla",
     "Add participants" : "Lisää osallistujat",
+    "Back" : "Takaisin",
     "Create conversation" : "Luo keskustelu",
     "Close" : "Sulje",
     "Choose a password" : "Valitse salasana",
@@ -265,47 +293,81 @@ OC.L10N.register(
     "An error occurred while performing the search" : "Hakua suorittaessa tapahtui virhe",
     "Conversation name" : "Keskustelun nimi",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
+    "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
+    "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
+    "Microphone" : "Mikrofoni",
     "Camera" : "Kamera",
+    "No microphone available" : "Ei mikrofonia saatavilla",
+    "Select microphone" : "Valitse mikrofoni",
+    "No camera available" : "Ei kameraa saatavilla",
+    "Select camera" : "Valitse kamera",
     "Reply" : "Vastaa",
     "Remove" : "Poista",
+    "Scroll to bottom" : "Vieritä alas",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
-    "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
+    "Share files to the conversation" : "Jaa tiedostoja keskusteluun",
     "Upload new files" : "Lähetä uusia tiedostoja",
+    "Add emoji" : "Lisää emoji",
     "Send message" : "Lähetä viesti",
     "File to share" : "Jaettava tiedosto",
+    "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
     "Invalid path selected" : "Valittu virheellinen polku",
+    "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
+    "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
     "Enabled" : "Käytössä",
+    "Show matterbridge log" : "Näytä matterbridge-loki",
     "Save" : "Tallenna",
+    "Nextcloud user" : "Nextcloud-käyttäjä",
+    "Matrix channel" : "Matrix-kanava",
+    "Mattermost user" : "Mattermost-käyttäjä",
+    "Channel name" : "Kanavan nimi",
+    "User name or e-mail address" : "Käyttäjänimi tai sähköpostiosoite",
     "Password" : "Salasana",
+    "Rocket.Chat channel" : "Rocket.Chat-kanava",
     "API token" : "API-poletti",
     "Login" : "Kirjaudu",
     "Nickname" : "Nimimerkki",
+    "Connection password" : "Yhteyden salasana",
+    "IRC channel" : "IRC-kanava",
+    "NickServ nickname" : "NickServ-nimimerkki",
+    "NickServ password" : "NickServ-salasana",
+    "Use TLS" : "Käytä TLS:ää",
+    "Use SASL" : "Käytä SASL:ia",
+    "Skip TLS verification" : "Ohita TLS-vahvistus",
     "Client ID" : "Asiakkaan tunniste",
+    "Bridge saved" : "Silta tallennettu",
     "moderator" : "moderaattori",
     "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
     "Promote to moderator" : "Ylennä moderaattoriksi",
     "Remove participant" : "Poista osallistuja",
+    "Add users" : "Lisää käyttäjiä",
     "Add groups" : "Lisää ryhmiä",
     "Add emails" : "Lisää sähköpostiosoitteita",
     "Add circles" : "Lisää piirejä",
     "Searching …" : "Haetaan…",
     "No results" : "Ei tuloksia",
+    "Add users, groups or circles" : "Lisää käyttäjiä, ryhmiä tai piirejä",
     "Add users or groups" : "Lisää käyttäjiä tai ryhmiä",
+    "Add users or circles" : "Lisää käyttäjiä tai piirejä",
     "Add groups or circles" : "Lisää ryhmiä tai piirejä",
     "Add other sources" : "Lisää muita lähteitä",
-    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
     "Participants" : "Osallistujat",
     "Chat" : "Keskustelu",
     "Display name: " : "Näyttönimi:",
     "Edit" : "Muokkaa",
+    "Choose devices" : "Valitse laitteet",
+    "Attachments folder" : "Liitteiden kansio",
     "Keyboard shortcuts" : "Pikanäppäimet",
+    "Focus the chat input" : "Kohdista keskustelun syötteeseen",
     "Search" : "Etsi",
+    "Select location for attachments" : "Valitse sijainti liitteille",
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Start call" : "Aloita puhelu",
+    "Toggle fullscreen" : "Koko näyttö päälle/pois",
     "Go to file" : "Siirry tiedostoon",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
     "Share link" : "Jaa linkki",
@@ -313,11 +375,16 @@ OC.L10N.register(
     "Enter a password" : "Syötä salasana",
     "Enable lobby" : "Käytä aulaa",
     "Start time (optional)" : "Aloitusaika (valinnainen)",
+    "Mute others" : "Mykistä muut",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
     "Fullscreen (f)" : "Koko näytön tila (f)",
     "Grid view" : "Ruudukkonäkymä",
+    "Send" : "Lähetä",
+    "Add more files" : "Lisää enemmän tiedostoja",
+    "No unread mentions" : "Ei lukemattomia mainintoja",
     "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
     "Start a conversation" : "Aloita keskustelu",
+    "You were mentioned" : "Sinut mainittiin",
     "Message without mention" : "Viesti ilman mainintaa",
     "Mention room" : "Mainitse huone",
     "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
@@ -325,9 +392,16 @@ OC.L10N.register(
     "Link to a conversation" : "Linkki keskusteluun",
     "Select conversation" : "Valitse keskustelu",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
+    "Do not disturb" : "Älä häiritse",
+    "Away" : "Poissa",
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
+    "Join here" : "Liity tähän",
+    "Leave this page" : "Poistu tältä sivulta",
     "Error while uploading file" : "Virhe tiedostoa lähettäessä",
     "Default" : "Oletus",
+    "Microphone {number}" : "Mikrofoni {number}",
+    "Camera {number}" : "Kamera {number}",
+    "Speaker {number}" : "Kaiutin {number}",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vaikuttaa siltä, että puhut vaikka sinut on mykistetty. Poista mykistys, jotta muut kuulevat sinut",
     "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
     "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
@@ -343,63 +417,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Liity keskusteluihin milloin tahansa, mistä tahansa ja miltä tahansa laitteelta.",
     "Android app" : "Android-sovellus",
     "iOS app" : "iOS-sovellus",
-    "Enter name for a new conversation" : "Anna nimi uudelle keskustelulle",
-    "{name} (public)" : "{name} (julkinen)",
-    "New conversation …" : "Uusi keskustelu…",
-    "Projects" : "Projektit",
-    "Copy" : "Kopioi",
-    "Copied!" : "Kopioitu!",
-    "Not supported!" : "Ei tuettu!",
-    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
-    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
-    "Error while getting the room ID" : "Virhe haettaessa huoneen ID-tunnistetta",
-    "Room name can not be empty" : "Huoneen nimi ei voi olla tyhjä",
-    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
-    "Password required" : "Salasana vaaditaan",
-    "Cancel" : "Peru",
-    "Submit" : "Lähetä",
-    "Calls are disabled in this conversation." : "Puhelut on poistettu käytöstä tässä keskustelussa.",
-    "Guests" : "Vieraat",
-    "Webinar" : "Webinaari",
-    "Change password" : "Vaihda salasana",
-    "Set password" : "Aseta salasana",
-    "Error occurred while renaming the conversation" : "Keskustelua nimettäessä uudelleen tapahtui virhe",
-    "Rename" : "Nimeä uudelleen",
-    "Link copied!" : "Linkki kopioitu!",
-    "Conversation with {name}" : "Keskustelu henkilön {name} kanssa",
-    "Error occurred while making the conversation public" : "Keskustelua tehtäessä julkiseksi tapahtui virhe",
-    "Error occurred while making the conversation private" : "Keskustelua tehtäessä yksityiseksi tapahtui virhe",
-    "Error occurred while setting password" : "Virhe salasanaa asettaessa",
-    "Invalid start time format" : "Virheellinen aloitusajan muoto",
-    "No messages yet, start the conversation!" : "Ei vielä viestejä, aloita keskustelu!",
-    "New message …" : "Uusi viesti …",
-    "Send" : "Lähetä",
-    "You can not send messages, because the conversation is locked." : "Et voi lähettää viestejä, koska keskustelu on lukittu.",
-    "The conversation is locked." : "Keskustelu on lukittu.",
-    "Share" : "Jaa",
-    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
-    "The message you are trying to send is too long" : "Viesti, jonka yrität lähettää, on liian pitkä",
-    "Error occurred while sending message" : "Viestiä lähettäessä tapahtui virhe",
-    "Error while sharing" : "Virhe jaettaessa",
     "No other people in this call" : "Ei muita henkilöitä tässä puhelussa",
-    "Waiting for {participantName} to join the call …" : "Odotetaan henkilön {participantName} liittymistä puheluun...",
-    "WebRTC is not supported in your browser :-/" : "WebRTC ei ole tuettuna selaimessasi :-/",
-    "Waiting for camera and microphone permissions" : "Odotetaan käyttöoikeuden myöntämistä kameralle ja mikrofonille",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Anna selaimellesi oikeus käyttää kameraa ja mikrofonia käyttääksesi tätä sovellusta.",
-    "Set your name in the chat window so other participants can identify you better." : "Aseta nimesi keskusteluikkunassa, jotta muut osalliset tunnistavat sinut.",
-    "Share screen" : "Jaa näyttö",
-    "No Camera" : "Ei kameraa",
-    "Screensharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
-    "Error while removing user from room" : "Virhe poistaessa käyttäjää huoneesta",
-    "Add participant …" : "Lisää osallistuja…",
-    "Favorited" : "Lisätty suosikkeihin",
     "Your screen" : "Sinun näyttösi",
-    "{participantName}'s screen" : "Henkilön {participantName} näyttö",
-    "Guest's screen" : "Vieraan näyttö",
-    "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
-    "Who can start a call?" : "Kuka voi aloittaa puhelun?",
-    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
-    "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Contacts" : "Yhteystiedot",
     "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
     "Contacts and groups" : "Yhteystiedot ja ryhmät",
@@ -407,11 +426,25 @@ OC.L10N.register(
     "Loading contacts" : "Ladataan yhteystietoja",
     "Select participants" : "Valitse osallistujat",
     "Search conversations or contacts" : "Hae keskusteluja tai yhteystietoja",
+    "[Unknown user name]" : "[Tuntematon käyttäjänimi]",
     "Contacts loading" : "Yhteystiedot latautuvat",
+    "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
     "Add contacts" : "Lisää yhteystietoja",
     "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
     "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
     "Add contacts or circles" : "Lisää yhteystietoja tai piirejä",
+    "Guests" : "Vieraat",
+    "Webinar" : "Webinaari",
+    "Projects" : "Projektit",
+    "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
+    "Who can start a call?" : "Kuka voi aloittaa puhelun?",
+    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
+    "Please enter the password for this call" : "Anna salasana tälle puhelulle",
+    "Password required" : "Salasana vaaditaan",
+    "Cancel" : "Peru",
+    "Submit" : "Lähetä",
+    "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
+    "Default location for attachments" : "Oletussijainti liitteille",
     "Select default location for attachments" : "Valitse liitteiden oletussijainti"
 },
 "nplurals=2; plural=(n != 1);");
