@@ -375,7 +375,6 @@ OC.L10N.register(
     "Enable video" : "הפעלת וידאו",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
-    "Back" : "חזרה",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
@@ -405,6 +404,7 @@ OC.L10N.register(
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Password protect" : "הגנה בססמה",
     "Add participants" : "הוספת משתתפים",
+    "Back" : "חזרה",
     "Create conversation" : "יצירת דיון",
     "Close" : "סגירה",
     "Choose a password" : "בחירת ססמה",
@@ -448,7 +448,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "הוספת קבוצות או מעגלים",
     "Add other sources" : "הוספת מקורות אחרים",
-    "Add participants to the conversation" : "הוספת משתתפים לדיון",
     "Participants" : "משתתפים",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Chat" : "צ׳אט",
@@ -467,6 +466,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
     "Fullscreen (f)" : "מסך מלא (f)",
     "Grid view" : "תצוגת טבלה",
+    "Send" : "שליחה",
     "Start a conversation" : "התחלת דיון",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
@@ -489,57 +489,27 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "New conversation …" : "דיון חדש…",
-    "Projects" : "מיזמים",
-    "Copy" : "העתקה",
-    "Copied!" : "הועתק!",
-    "Not supported!" : "אין תמיכה!",
-    "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
-    "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
-    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
-    "Password required" : "נדרשת ססמה",
-    "Cancel" : "ביטול",
-    "Submit" : "שליחה",
-    "Guests" : "אורחים",
-    "Webinar" : "סמינר מקוון",
-    "Change password" : "החלפת ססמה",
-    "Set password" : "הגדרת ססמה",
-    "Rename" : "שינוי שם",
-    "Link copied!" : "קישור הועתק!",
-    "Conversation with {name}" : "דיון עם {name}",
-    "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
-    "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
-    "New message …" : "הודעה חדשה…",
-    "Send" : "שליחה",
-    "Share" : "שיתוף",
-    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
-    "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
-    "Error while sharing" : "שגיאה בעת השיתוף",
     "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
-    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
-    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
-    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
-    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
-    "Share screen" : "שיתוף המסך",
-    "No Camera" : "אין מצלמה",
-    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
-    "Add participant …" : "הוספת משתתף…",
-    "Favorited" : "סומן כמועדף",
     "Your screen" : "המסך שלך",
-    "{participantName}'s screen" : "המסך של {participantName}",
-    "Guest's screen" : "המסך של האורח/ת",
-    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
-    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
-    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
     "Contacts" : "אנשי קשר",
     "Contacts and groups" : "אנשי קשר וקבוצות",
     "Contacts and circles" : "אנשי קשר ומעגלים",
     "Search conversations or contacts" : "חיפוש דיונים או אנשי קשר",
+    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
     "Search for more contacts" : "חיפוש אחר אנשי קשר נוספים",
+    "Add participants to the conversation" : "הוספת משתתפים לדיון",
     "Add contacts" : "הוספת אנשי קשר",
     "Add contacts, groups or circles" : "הוספת אנשי קשר, קבוצות או מעגלים",
     "Add contacts or groups" : "הוספת אנשי קשר או קבוצות",
-    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים"
+    "Add contacts or circles" : "הוספת אנשי קשר או מעגלים",
+    "Guests" : "אורחים",
+    "Webinar" : "סמינר מקוון",
+    "Projects" : "מיזמים",
+    "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
+    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
+    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
+    "Password required" : "נדרשת ססמה",
+    "Cancel" : "ביטול",
+    "Submit" : "שליחה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
