@@ -17,7 +17,6 @@ OC.L10N.register(
     "TCP only" : "solo TCP",
     "Copy link" : "Copiar ligamine",
     "Dismiss" : "Dimitter",
-    "Back" : "Retro",
     "You" : "Tu",
     "Favorite" : "Favorite",
     "Remove from favorites" : "Remove from favorites",
@@ -26,6 +25,7 @@ OC.L10N.register(
     "Groups" : "Gruppos",
     "Settings" : "Configurationes",
     "Password protect" : "Proteger per contrasigno",
+    "Back" : "Retro",
     "Close" : "Clauder",
     "Reply" : "Responder",
     "Today" : "Hodie",
@@ -43,6 +43,7 @@ OC.L10N.register(
     "Share link" : "Compartir ligamine",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
+    "Send" : "Inviar",
     "Access to microphone & camera is only possible with HTTPS" : "Accesso al microphono e al camera solmente es possibile per HTTPS",
     "Access to microphone & camera was denied" : "Accesso al microphono e al camera solmente esseva negate",
     "WebRTC is not supported in your browser" : "WebRTC non es supportate per tu navigator",
@@ -52,19 +53,7 @@ OC.L10N.register(
     "TURN server" : "servitor TURN",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
-    "Copy" : "Copiar",
-    "Copied!" : "Copiate!",
-    "Not supported!" : "Non supportate!",
-    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
-    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
-    "Cancel" : "Cancellar",
-    "Change password" : "Cambiar contrasigno",
-    "Rename" : "Renominar",
-    "Send" : "Inviar",
-    "Share" : "Compartir",
-    "Error while sharing" : "Error al compartir",
-    "WebRTC is not supported in your browser :-/" : "WebRTC non es supportate per tu navigator  :-/",
-    "Favorited" : "Favorite",
-    "Contacts" : "Contactos"
+    "Contacts" : "Contactos",
+    "Cancel" : "Cancellar"
 },
 "nplurals=2; plural=(n != 1);");
