@@ -20,7 +20,6 @@ OC.L10N.register(
     "Saved" : "Disimpan",
     "Copy link" : "Salin tautan",
     "Dismiss" : "Batal",
-    "Back" : "Kembali",
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
@@ -29,6 +28,7 @@ OC.L10N.register(
     "Groups" : "Grup",
     "Settings" : "Setelan",
     "Password protect" : "Lindungi dengan kata sandi",
+    "Back" : "Kembali",
     "Close" : "Tutup",
     "Reply" : "Balas",
     "Remove" : "Buang",
@@ -51,25 +51,14 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Enter a password" : "Masukkan kata sandi",
     "Grid view" : "Tampilan kotak",
+    "Send" : "Kirim",
     "Default" : "Bawaan",
     "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
+    "Contacts" : "Kontak",
     "Projects" : "Proyek",
-    "Copy" : "Salin",
-    "Copied!" : "Tersalin!",
-    "Not supported!" : "Tidak didukung!",
-    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
-    "Press Ctrl-C to copy." : "Tekan CTRL-C untuk menyalin.",
     "Password required" : "Kata sandi diperlukan",
-    "Cancel" : "Membatalkan",
-    "Change password" : "Ubah kata sandi",
-    "Set password" : "Atur kata sandi",
-    "Rename" : "Ubah nama",
-    "Send" : "Kirim",
-    "Share" : "Bagikan",
-    "Error while sharing" : "Kesalahan saat membagikan",
-    "Favorited" : "Difavoritkan",
-    "Contacts" : "Kontak"
+    "Cancel" : "Membatalkan"
 },
 "nplurals=1; plural=0;");
