@@ -417,7 +417,6 @@ OC.L10N.register(
     "Enable video" : "Virkja myndskeið",
     "Screensharing options" : "Valkostir skjádeilingar",
     "Enable screensharing" : "Virkja skjádeilingu",
-    "Back" : "Til baka",
     "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
     "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
@@ -436,6 +435,7 @@ OC.L10N.register(
     "Circles" : "Hringir",
     "Settings" : "Stillingar",
     "Password protect" : "Verja með lykilorði",
+    "Back" : "Til baka",
     "Close" : "Loka",
     "Conversation name" : "Heiti samtals",
     "Camera" : "Myndavél",
@@ -477,6 +477,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
     "Fullscreen (f)" : "Fylla skjáinn (f)",
     "Grid view" : "Reitasýn",
+    "Send" : "Senda",
     "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
     "Start a conversation" : "Hefja samtal",
     "Link to a conversation" : "Tengill á samtal",
@@ -499,64 +500,19 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
     "Android app" : "Android-forrit",
     "iOS app" : "iOS-forrit",
-    "Enter name for a new conversation" : "Settu inn nafn fyrir nýtt samtal",
-    "{name} (public)" : "{name} (opinbert)",
-    "New conversation …" : "Nýtt samtal…",
+    "No other people in this call" : "Engir aðrir í þessu símtali",
+    "Your screen" : "Skjárinn þinn",
+    "Contacts" : "Tengiliðir",
+    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum",
+    "[Unknown user name]" : "[nafn óþekkts notanda]",
+    "Guests" : "Gestir",
     "Projects" : "Verkefni",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
-    "Copy" : "Afrita",
-    "Copied!" : "Afritað!",
-    "Not supported!" : "Ekki stutt!",
-    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
-    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
-    "Error while getting the room ID" : "Villa kom upp við að sækja auðkennisnúmer spjallsvæðis",
-    "Room name can not be empty" : "Nafn á spjallsvæði má ekki vera autt",
+    "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
+    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
     "Please enter the password for this call" : "Settu inn lykilorðið fyrir þetta símtal",
     "Password required" : "Lykilorðs er krafist",
     "Cancel" : "Hætta við",
     "Submit" : "Senda inn",
-    "Calls are disabled in this conversation." : "Símtöl eru óvirk í þessu samtali",
-    "Guests" : "Gestir",
-    "Change password" : "Breyta lykilorði",
-    "Set password" : "Stilltu lykilorð",
-    "Rename" : "Endurnefna",
-    "Link copied!" : "Tengill afritaður!",
-    "Conversation with {name}" : "Samtal við {name}",
-    "Error occurred while setting password" : "Villa kom upp við að stilla lykilorð",
-    "No messages yet, start the conversation!" : "Engin skilaboð ennþá, byrjaðu umræðuna!",
-    "New message …" : "Ný skilaboð …",
-    "Send" : "Senda",
-    "You can not send messages, because the conversation is locked." : "Þú getur ekki sent skilaboð því samtalið er læst.",
-    "The conversation is locked." : "Samtalið er læst.",
-    "Share" : "Deila",
-    "[Unknown user name]" : "[nafn óþekkts notanda]",
-    "The message you are trying to send is too long" : "Skilaboðin sem þú ert að reyna að senda eru of löng",
-    "Error occurred while sending message" : "Villa kom upp við að senda inn skilaboð",
-    "Error while sharing" : "Villa við deilingu",
-    "No other people in this call" : "Engir aðrir í þessu símtali",
-    "Waiting for {participantName} to join the call …" : "Bíð eftir að {participantName} komi inn í símtalið …",
-    "WebRTC is not supported in your browser :-/" : "WebRTC er ekki stutt í vafranum þínum :-/",
-    "Waiting for camera and microphone permissions" : "Bíð eftir heimildum fyrir hljóðnema og myndavél",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Til að nota þetta forrit, þarftu að gefa vafranum þínum heimild til að nota hljóðnema og myndavél.",
-    "Set your name in the chat window so other participants can identify you better." : "Settu nafnið þitt í spjallgluggann svo að aðrir þáttakendur eigi auðveldara með að þekkja þig.",
-    "Share screen" : "Deila skjá",
-    "No Camera" : "Engin myndavél",
-    "Screensharing is not supported by your browser." : "Deiling á skjá er ekki studd í vafranum þínum",
-    "Error while promoting user to moderator" : "Villa við að gera notanda að umsjónarmanni",
-    "Error while demoting moderator" : "Villa við að láta hætta sem umsjónarmann",
-    "Error while removing user from room" : "Villa við að fjarlægja notanda úr spjallsvæði",
-    "Add participant …" : "Bæta við þátttakanda…",
-    "Favorited" : "Sett í eftirlæti",
-    "Your screen" : "Skjárinn þinn",
-    "{participantName}'s screen" : "Skjár {participantName}",
-    "Guest's screen" : "Skjár gests",
-    "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Skipanir er nýr eiginleiki í Nextcloud Talk. Þær gera þér kleift að keyra skriftur á Nextcloud-þjóninum þínum. Þú getur skilgreint þær með skipanalínuviðmóti okkar. Þæmi um reiknivélarskriftu má finna í <a {attributes}>hjálparskjölunum ↗</a>.",
-    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
-    "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
-    "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er.",
-    "Contacts" : "Tengiliðir",
-    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum",
     "Signaling server URL" : "Slóð á merkjasendingaþjón"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
