@@ -90,7 +90,6 @@ OC.L10N.register(
     "Enable video" : "비디오 활성화",
     "Screensharing options" : "화면 공유 옵션",
     "Enable screensharing" : "화면 공유 활성화",
-    "Back" : "뒤로",
     "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
     "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
     "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
@@ -110,6 +109,7 @@ OC.L10N.register(
     "Circles" : "서클",
     "Settings" : "설정",
     "Password protect" : "암호 보호",
+    "Back" : "뒤로",
     "Close" : "닫기",
     "Conversation name" : "대화명",
     "Camera" : "카메라",
@@ -144,6 +144,7 @@ OC.L10N.register(
     "Password protection" : "암호 보호",
     "Enter a password" : "Enter a password",
     "Grid view" : "바둑판식 보기",
+    "Send" : "보내기",
     "Start a conversation" : "대화 시작",
     "Default" : "기본값",
     "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
@@ -157,40 +158,15 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "대규모 사용자가 필요한 경우 외부 신호 서버를 사용할 수 있습니다. 비워 두면 내장 신호 서버를 사용합니다.",
     "Android app" : "Android 앱",
     "iOS app" : "iOS 앱",
+    "No other people in this call" : "이 통화에 다른 사람이 없음",
+    "Your screen" : "내 화면",
+    "Contacts" : "연락처",
+    "[Unknown user name]" : "[알 수 없는 사용자 이름]",
+    "Guests" : "손님",
     "Projects" : "프로젝트",
-    "Copy" : "복사",
-    "Copied!" : "복사 성공!",
-    "Not supported!" : "지원하지 않음!",
-    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
-    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
     "Please enter the password for this call" : "이 통화의 암호를 입력하십시오",
     "Password required" : "암호가 필요함",
     "Cancel" : "취소",
-    "Submit" : "제출",
-    "Guests" : "손님",
-    "Change password" : "암호 변경",
-    "Set password" : "암호 설정",
-    "Rename" : "이름 바꾸기",
-    "Link copied!" : "링크 복사됨!",
-    "Conversation with {name}" : "{name} 님과 대화",
-    "No messages yet, start the conversation!" : "메시지가 없습니다. 대화를 시작하십시오!",
-    "Send" : "보내기",
-    "Share" : "공유",
-    "[Unknown user name]" : "[알 수 없는 사용자 이름]",
-    "Error occurred while sending message" : "메시지를 보내는 중 오류 발생",
-    "Error while sharing" : "공유하는 중 오류 발생",
-    "No other people in this call" : "이 통화에 다른 사람이 없음",
-    "Waiting for {participantName} to join the call …" : "{participantName} 님을 기다리는 중…",
-    "WebRTC is not supported in your browser :-/" : "웹 브라우저에서 WebRTC를 지원하지 않습니다 :-/",
-    "Waiting for camera and microphone permissions" : "카메라와 마이크 권한을 기다리는 중",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "이 앱을 사용하려면 웹 브라우저에 카메라 및 마이크 사용 권한을 부여해야 합니다.",
-    "Share screen" : "화면 공유",
-    "No Camera" : "카메라 없음",
-    "Screensharing is not supported by your browser." : "웹 브라우저에서 화면 공유를 지원하지 않습니다.",
-    "Favorited" : "즐겨찾기에 추가됨",
-    "Your screen" : "내 화면",
-    "{participantName}'s screen" : "{participantName} 님의 화면",
-    "Guest's screen" : "손님의 화면",
-    "Contacts" : "연락처"
+    "Submit" : "제출"
 },
 "nplurals=1; plural=0;");
