@@ -412,7 +412,6 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
-    "Back" : "Atgal",
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
@@ -423,7 +422,6 @@ OC.L10N.register(
     "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
     "Mute" : "Nutildyti",
-    "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Favorite" : "Mėgstamas",
     "Conversation settings" : "Pokalbio nustatymai",
     "Chat notifications" : "Pokalbio pranešimai",
@@ -453,6 +451,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
     "Add participants" : "Pridėti dalyvius",
+    "Back" : "Atgal",
     "Create conversation" : "Sukurti pokalbį",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
@@ -476,10 +475,10 @@ OC.L10N.register(
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
     "Share from Files" : "Bendrinti iš Failų",
     "Send message" : "Siųsti žinutę",
     "File to share" : "Failas, kurį bendrinti",
+    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Enabled" : "Įjungta",
     "Save" : "Įrašyti",
@@ -516,7 +515,6 @@ OC.L10N.register(
     "Add users or groups" : "Pridėti naudotojus ar grupes",
     "Add groups or circles" : "Pridėti grupes ar ratus",
     "Add other sources" : "Pridėti kitus šaltinius",
-    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
     "Participants" : "Dalyviai",
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
@@ -538,6 +536,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
     "Fullscreen (f)" : "Visas ekranas (f)",
     "Grid view" : "Tinklelio rodinys",
+    "Send" : "Siųsti",
     "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
     "Start a conversation" : "Pradėti pokalbį",
     "Message without mention" : "Rašyti be paminėjimo",
@@ -574,82 +573,33 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
-    "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
-    "{name} (public)" : "{name} (viešas)",
-    "New conversation …" : "Naujas pokalbis …",
-    "Projects" : "Projektai",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio gali būti patiriamos ryšio problemos ir sukeliama didelė apkrova dalyvaujantiems įrenginiams.",
-    "Copy" : "Kopijuoti",
-    "Copied!" : "Nukopijuota!",
-    "Not supported!" : "Nepalaikoma!",
-    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
-    "Error while getting the room ID" : "Klaida gaunant kambario ID",
-    "Room name can not be empty" : "Kambario pavadinimas negali būti tuščias",
-    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
-    "Password required" : "Reikalingas slaptažodis",
-    "Cancel" : "Atsisakyti",
-    "Submit" : "Pateikti",
-    "Calls are disabled in this conversation." : "Šiame pokalbyje skambinti negalima.",
-    "Guests" : "Svečiai",
-    "Webinar" : "Internetinis seminaras",
-    "Only moderators can enter the conversation when the lobby is enabled" : "Įjungus laukimo salę, į pokalbį galės užeiti tik moderatoriai",
-    "Change password" : "Pakeisti slaptažodį",
-    "Set password" : "Nustatyti slaptažodį",
-    "Error occurred while renaming the conversation" : "Klaida pervadinant pokalbį",
-    "Rename" : "Pervadinti",
-    "Link copied!" : "Nuoroda nukopijuota!",
-    "Conversation with {name}" : "Pokalbis su {name}",
-    "Error occurred while setting password" : "Nustatant slaptažodį, atsirado klaidų",
-    "Error occurred while changing lobby state" : "Klaida keičiant laukimo salės būseną",
-    "Invalid start time format" : "Neteisingas pradžios laiko formatas",
-    "Error occurred while setting the lobby start time" : "Klaida nustatant laukimo salės pradžios laiką",
-    "No messages yet, start the conversation!" : "Kol kas žinučių nėra, pradėkite pokalbį!",
-    "New message …" : "Nauja žinutė…",
-    "Send" : "Siųsti",
-    "You can not send messages, because the conversation is locked." : "Negalite siųsti žinučių, nes pokalbis užrakintas.",
-    "The conversation is locked." : "Pokalbis užrakintas.",
-    "Share" : "Bendrinti",
-    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
-    "The message you are trying to send is too long" : "Žinutė, kurią bandote išsiųsti yra pernelyg ilga",
-    "Error occurred while sending message" : "Siunčiant žinutę, įvyko klaida",
-    "Error while sharing" : "Klaida bendrinant",
     "No other people in this call" : "Šiame skambutyje nėra kitų žmonių",
-    "Waiting for {participantName} to join the call …" : "Laukiama, kol {participantName} prisijungs prie skambučio…",
-    "WebRTC is not supported in your browser :-/" : "Jūsų naršyklėje WebRTC nėra palaikoma :-/",
-    "Waiting for camera and microphone permissions" : "Laukiama kameros ir mikrofono leidimų",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Norėdami naudoti šią programėlę, suteikite savo naršyklei prieigą naudoti jūsų kamerą ir mikrofoną.",
-    "Set your name in the chat window so other participants can identify you better." : "Nustatykite pokalbio lange savo vardą, kad kiti dalyviai galėtų lengviau jus atpažinti.",
-    "Share screen" : "Bendrinti ekraną",
-    "No Camera" : "Nėra jokios kameros",
-    "Screensharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
-    "Error while promoting user to moderator" : "Klaida paaukštinant naudotoją į moderatorius",
-    "Error while demoting moderator" : "Klaida pažeminant iš moderatorių",
-    "Error while removing user from room" : "Klaida šalinant naudotoją iš kambario",
-    "Add participant …" : "Pridėti dalyvį…",
-    "Favorited" : "Pažymėtas mėgstamu",
     "Your screen" : "Jūsų ekranas",
-    "{participantName}'s screen" : "Dalyvio {participantName} ekranas",
-    "Guest's screen" : "Svečio ekranas",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Dabar, pokalbiuose yra laukimo salė. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti.",
-    "{email} tried to requested the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
-    "Someone tried to requested the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
-    "Start calls" : "Pradeda skambučius",
-    "Who can start a call?" : "Kas gali pradėti skambutį?",
-    "Join conversations at any time, any where, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Contacts" : "Adresatai",
     "Contacts, groups and circles" : "Adresatai, grupės ir ratai",
     "Contacts and groups" : "Adresatai ir grupės",
     "Contacts and circles" : "Adresatai ir ratai",
     "Loading contacts" : "Įkeliami adresatai",
     "Search conversations or contacts" : "Ieškoti pokalbių ar adresatų",
+    "[Unknown user name]" : "[Nežinomas naudotojo vardas]",
     "Search for more contacts" : "Ieškoti daugiau adresatų",
     "Contacts loading" : "Įkeliami adresatai",
+    "Add participants to the conversation" : "Pridėti dalyvius į pokalbį",
     "Add contacts" : "Pridėti adresatus",
     "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
     "Add contacts or groups" : "Pridėti adresatus ar grupes",
     "Add contacts or circles" : "Pridėti adresatus ar ratus",
+    "Guests" : "Svečiai",
+    "Webinar" : "Internetinis seminaras",
+    "Projects" : "Projektai",
+    "Start calls" : "Pradeda skambučius",
+    "Who can start a call?" : "Kas gali pradėti skambutį?",
+    "Please enter the password for this call" : "Įveskite šio skambučio slaptažodį",
+    "Password required" : "Reikalingas slaptažodis",
+    "Cancel" : "Atsisakyti",
+    "Submit" : "Pateikti",
     "Signaling server URL" : "Signalinio serverio URL",
+    "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Default location for attachments" : "Numatytoji priedų vieta",
     "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams"
 },
