@@ -341,7 +341,7 @@ OC.L10N.register(
     "This conversation has ended" : "Овој разговор е завршен",
     "Limit to groups" : "Ограничување на групи",
     "When a call has started, everyone with access to the conversation can join the call." : "Кога повикот е започнат, секој со пристап до разговорот може да се приклучи кон повикот.",
-    "Everyone" : "Секој",
+    "Everyone" : "Сите",
     "Users and moderators" : "Корисници и модератори",
     "Moderators only" : "Само модераторите",
     "Save changes" : "Зачувај ги промените",
@@ -397,7 +397,6 @@ OC.L10N.register(
     "Enable video" : "Овозможи видео",
     "Screensharing options" : "Опции за споделување на екранот",
     "Enable screensharing" : "Овозможи споделување на екранот",
-    "Back" : "Назад",
     "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
     "You" : "Ти",
@@ -427,6 +426,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Password protect" : "Заштити со лозинка",
     "Add participants" : "Додади учесници",
+    "Back" : "Назад",
     "Create conversation" : "Креирајте разговор",
     "Close" : "Затвори",
     "Choose a password" : "Избери лозинка",
@@ -441,14 +441,15 @@ OC.L10N.register(
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Напиши порака, @ за да споменте некој ...",
     "Upload new files" : "Прикачи нови датотеки",
     "Share from Files" : "Сподели од датотеките",
     "File to share" : "Датотека за споделување",
+    "Write message, @ to mention someone …" : "Напиши порака, @ за да споменте некој ...",
     "Invalid path selected" : "Избрана невалидна патека",
     "Enabled" : "Овозможен",
     "Save" : "Зачувај",
     "Password" : "Лозинка",
+    "API token" : "API токен",
     "Login" : "Login",
     "Nickname" : "Прекар",
     "Client ID" : "Клиент ИД",
@@ -464,7 +465,6 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Add groups or circles" : "Додади групи или кругови",
     "Add other sources" : "Додади други извори",
-    "Add participants to the conversation" : "Додадете учесници кон разговорот",
     "Participants" : "Учесници",
     "Chat" : "Разговор",
     "Display name: " : "Име:",
@@ -483,11 +483,14 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Излез од цел екран (f)",
     "Fullscreen (f)" : "Приказ на цел екран (f)",
     "Grid view" : "Мрежа",
+    "Send" : "Испрати",
     "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
     "Start a conversation" : "Започни разговор",
     "Link to a conversation" : "Линк до разговорот",
     "Select conversation" : "Избери разговор",
     "Join a conversation or start a new one" : "Приклучи се кон разговор или започни нов",
+    "Do not disturb" : "Не вознемирувај",
+    "Away" : "Далеку",
     "Error while sharing file" : "Грешка при споделување на датотека",
     "Error while uploading file" : "Грешка при прикачување на датотека",
     "Default" : "Стандардно",
@@ -497,55 +500,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
     "Android app" : "Android апликација",
     "iOS app" : "iOS апликација",
-    "Enter name for a new conversation" : "Внеси име за нов разговор",
-    "{name} (public)" : "{name} (јавно)",
-    "New conversation …" : "Нов разговор ...",
-    "Projects" : "Проекти",
-    "Copy" : "Копирај",
-    "Copied!" : "Копирано!",
-    "Not supported!" : "Не е поддржано!",
-    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
-    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
-    "Room name can not be empty" : "Името на собата неможе да биде празно",
-    "Please enter the password for this call" : "Внесете лозинка за да пристапите кон овој разговор",
-    "Password required" : "Потребна е лозинка",
-    "Cancel" : "Откажи",
-    "Submit" : "Испрати",
-    "Calls are disabled in this conversation." : "Повиците се оневозможени во овој разговор.",
-    "Guests" : "Гости",
-    "Webinar" : "Вебинар",
-    "Only moderators can enter the conversation when the lobby is enabled" : "Само модератори можат да влезат во разговор кога лобито е овозможено",
-    "Change password" : "Промени лозинка",
-    "Set password" : "Постави лозинка",
-    "Rename" : "Преименувај",
-    "Link copied!" : "Линкот е копиран!",
-    "Conversation with {name}" : "Разговор со {name}",
-    "Error occurred while setting password" : "Настана грешка при обидот за поставување на лозинка",
-    "Invalid start time format" : "Погрешен формат за време на почеток",
-    "No messages yet, start the conversation!" : "Сеуште нема пораки, започнете разговор!",
-    "New message …" : "Нова порака ...",
-    "Send" : "Испрати",
-    "You can not send messages, because the conversation is locked." : "Неможете да испратите порака, бидејќи разговорот е заклучен.",
-    "The conversation is locked." : "Разговорот е заклучен.",
-    "Share" : "Сподели",
-    "[Unknown user name]" : "[Непознато корисничко име]",
-    "The message you are trying to send is too long" : "Пораката која се обидувате да ја испратите е премногу долга",
-    "Error occurred while sending message" : "Настана грешка при обидот за испраќање на порака",
-    "Error while sharing" : "Грешка при споделување",
     "No other people in this call" : "Нема други луѓе во овој повик",
-    "Waiting for {participantName} to join the call …" : "Чекање за {participantName} да се приклучи кон повикот …",
-    "Waiting for camera and microphone permissions" : "Чекање за дозвола на камера и микрофон",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Дозволете му на вашиот прелистувач пристап до вашата камера и микрофон за да можете да ја користите оваа аликација.",
-    "Set your name in the chat window so other participants can identify you better." : "Напишете го вашето име во прозорот за разговор за да можат другите учесници полесно да ве распознаваат.",
-    "Share screen" : "Сподели екран",
-    "No Camera" : "Нема камера",
-    "Add participant …" : "Додади учесници ...",
-    "Favorited" : "Омилени",
     "Your screen" : "Вашиот екран",
-    "{participantName}'s screen" : "Екранот на {participantName}",
-    "Guest's screen" : "Екранот на гостинот",
-    "Who can start a call?" : "Кој може да започне повик?",
-    "Join conversations at any time, any where, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
     "Contacts" : "Контакти",
     "Contacts, groups and circles" : "Контакти, групи и кругови",
     "Contacts and groups" : "Контакти и групи",
@@ -553,12 +509,22 @@ OC.L10N.register(
     "Loading contacts" : "Вчитување на контакти",
     "Select participants" : "Избери учесници",
     "Search conversations or contacts" : "Пребарување на разговори или контакти",
+    "[Unknown user name]" : "[Непознато корисничко име]",
     "Search for more contacts" : "Пребарување за повеќе контакти",
     "Contacts loading" : "Вчитување на контакти",
+    "Add participants to the conversation" : "Додадете учесници кон разговорот",
     "Add contacts" : "Додади контакти",
     "Add contacts, groups or circles" : "Додади контакти, групи или кругови",
     "Add contacts or groups" : "Додади контакти или групи",
     "Add contacts or circles" : "Додади контакти или кругови",
+    "Guests" : "Гости",
+    "Webinar" : "Вебинар",
+    "Projects" : "Проекти",
+    "Who can start a call?" : "Кој може да започне повик?",
+    "Please enter the password for this call" : "Внесете лозинка за да пристапите кон овој разговор",
+    "Password required" : "Потребна е лозинка",
+    "Cancel" : "Откажи",
+    "Submit" : "Испрати",
     "Signaling server URL" : "URL за сервер за сигнализација",
     "Default location for attachments" : "Стандардна локација за прилози",
     "Select default location for attachments" : "Избери стандардна локација за прилози"
