@@ -92,7 +92,6 @@ OC.L10N.register(
     "Enable video" : "activar vídeo",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Activar partilha de ecrã",
-    "Back" : "Anterior",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
@@ -110,6 +109,7 @@ OC.L10N.register(
     "Circles" : "Círculos",
     "Settings" : "Definições",
     "Password protect" : "Proteger com palavra-passe",
+    "Back" : "Anterior",
     "Close" : "Fechar",
     "Conversation name" : "Nome da conversação",
     "Camera" : "Câmera",
@@ -143,6 +143,7 @@ OC.L10N.register(
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
     "Grid view" : "Vista em grelha",
+    "Send" : "Enviar",
     "Start a conversation" : "Iniciar uma conversação",
     "Default" : "Predefinida",
     "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
@@ -153,41 +154,15 @@ OC.L10N.register(
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "Copy" : "Copiar",
-    "Copied!" : "Copiado!",
-    "Not supported!" : "Não suportado!",
-    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
-    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
+    "No other people in this call" : "Sem mais pessoas nesta chamada",
+    "Your screen" : "O seu ecrã",
+    "Contacts" : "Contactos",
+    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
+    "Guests" : "Convidados",
+    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
     "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
     "Password required" : "Necessário palavra-passe",
     "Cancel" : "Cancelar",
-    "Submit" : "Submeter",
-    "Guests" : "Convidados",
-    "Change password" : "Alterar palavra-passe",
-    "Set password" : "Definir palavra-passe",
-    "Rename" : "Renomear",
-    "Link copied!" : "Ligação copiada!",
-    "Conversation with {name}" : "Conversa com {name}",
-    "Error occurred while setting password" : "Ocorreu um erro a definir a palavra-passe",
-    "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
-    "New message …" : "Nova mensagem...",
-    "Send" : "Enviar",
-    "Share" : "Partilhar",
-    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
-    "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
-    "Error while sharing" : "Erro ao partilhar",
-    "No other people in this call" : "Sem mais pessoas nesta chamada",
-    "Waiting for {participantName} to join the call …" : "À espera que {participantName} se junte à chamada ..",
-    "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
-    "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
-    "No Camera" : "Sem Câmera",
-    "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
-    "Favorited" : "Nos Favoritos",
-    "Your screen" : "O seu ecrã",
-    "{participantName}'s screen" : "Ecrã de {participantName}",
-    "Guest's screen" : "Ecrã do convidado",
-    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
-    "Contacts" : "Contactos"
+    "Submit" : "Submeter"
 },
 "nplurals=2; plural=(n != 1);");
