@@ -477,7 +477,6 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
     "Screensharing options" : "Skärmdelningsalternativ",
     "Enable screensharing" : "Tillåt skärmdelning",
-    "Back" : "Tillbaka",
     "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
@@ -491,7 +490,6 @@ OC.L10N.register(
     "Mute" : "Tyst",
     "Stop following" : "Sluta följa",
     "You need to be logged in to upload files" : "Du måste vara inloggad för att ladda upp filer",
-    "This conversation is read only" : "Denna konversation är skrivskyddad",
     "Drop your files to upload" : "Släpp dina filer för att ladda upp",
     "Call in progress" : "Samtal pågår",
     "Favorite" : "Favorit",
@@ -511,7 +509,7 @@ OC.L10N.register(
     "No search results" : "Inga sökresultat",
     "Groups" : "Grupper",
     "Circles" : "Cirklar",
-    "Settings" : "Inställnigar",
+    "Settings" : "Inställningar",
     "Users, groups and circles" : "Användare, grupper och cirklar",
     "Users and groups" : "Användare och grupper",
     "Users and circles" : "Användare och cirklar",
@@ -525,6 +523,7 @@ OC.L10N.register(
     "Create a new group conversation" : "Skapa en ny gruppkonversation",
     "Password protect" : "Lösenordsskydda",
     "Add participants" : "Lägg till deltagare",
+    "Back" : "Tillbaka",
     "Create conversation" : "Skapa konversation",
     "Close" : "Stäng",
     "Choose a password" : "Välj ett lösenord",
@@ -542,12 +541,12 @@ OC.L10N.register(
     "Today" : "Idag",
     "Yesterday" : "Igår",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Write message, @ to mention someone …" : "Skriv meddelande, @ för att nämna någon ...",
     "Share files to the conversation" : "Dela filer till konversationen",
     "Upload new files" : "Ladda upp nya filer",
     "Share from Files" : "Dela från Filer",
     "Send message" : "Skicka meddelande",
     "File to share" : "Fil att dela",
+    "Write message, @ to mention someone …" : "Skriv meddelande, @ för att nämna någon ...",
     "Invalid path selected" : "Ogiltig sökväg vald",
     "Enabled" : "Aktiverad",
     "Save" : "Spara",
@@ -574,7 +573,6 @@ OC.L10N.register(
     "Add users or circles" : "Lägg till användare eller cirklar",
     "Add groups or circles" : "Lägg till grupper eller cirklar",
     "Add other sources" : "Lägg till andra källor",
-    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
     "Participants" : "Deltagare",
     "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Chat" : "Chat",
@@ -597,6 +595,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
     "Grid view" : "Rutnätsvy",
+    "Send" : "Skicka",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
     "Start a conversation" : "Starta en konversation",
     "Message without mention" : "Meddelande utan omnämnande",
@@ -636,75 +635,8 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
-    "Enter name for a new conversation" : "Ange namn för en ny konversation",
-    "{name} (public)" : "{name} (publik)",
-    "New conversation …" : "Ny konversation",
-    "Projects" : "Projekt",
-    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
-    "Copy" : "Kopiera",
-    "Copied!" : "Kopierat!",
-    "Not supported!" : "Stöds inte!",
-    "Press ⌘-C to copy." : "Tryck ⌘-C för att kopiera.",
-    "Press Ctrl-C to copy." : "Tryck Ctrl-C för att kopiera.",
-    "Error while getting the room ID" : "Fel vid mottagande av rum-ID",
-    "Room name can not be empty" : "Rumsnamn kan inte vara tomt",
-    "Please enter the password for this call" : "Vänligen ange lösenordet för detta samtal",
-    "Password required" : "Lösenord krävs",
-    "Cancel" : "Avbryt",
-    "Submit" : "Skicka",
-    "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
-    "Guests" : "Gäster",
-    "Webinar" : "Webinar",
-    "Only moderators can enter the conversation when the lobby is enabled" : "Endast moderatorer kan gå in i konversationen när lobbyn är aktiverad",
-    "Change password" : "Byt lösenord",
-    "Set password" : "Sätt lösenord",
-    "Error occurred while renaming the conversation" : "Fel uppstod vid namnändring av konversationen",
-    "Rename" : "Byt namn",
-    "Link copied!" : "Länk kopierad!",
-    "Conversation with {name}" : "Konversation med {name}",
-    "Error occurred while making the conversation public" : "Fel uppstod när konversationen skulle göras offentlig",
-    "Error occurred while making the conversation private" : "Fel uppstod när konversationen skulle göras privat",
-    "Error occurred while setting password" : "Fel inträffade när lösenord sattes",
-    "Error occurred while changing lobby state" : "Fel uppstod vid ändring av lobbyns status",
-    "Invalid start time format" : "Ogiltigt format för starttid",
-    "Error occurred while setting the lobby start time" : "Fel uppstod vid inställning av starttid för lobby",
-    "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
-    "New message …" : "Nytt meddelande",
-    "Send" : "Skicka",
-    "You can not send messages, because the conversation is locked." : "Du kan inte skicka meddelanden, eftersom konversationen är låst.",
-    "The conversation is locked." : "Konversationen är låst.",
-    "Share" : "Dela",
-    "[Unknown user name]" : "[Okänt användarnam]",
-    "The message you are trying to send is too long" : "Meddelandet du försöker skicka är för långt",
-    "Error occurred while sending message" : "Fel uppstod när meddelandet skickades",
-    "Error while sharing" : "Fel vid delning",
     "No other people in this call" : "Inga andra personer i detta samtal",
-    "Waiting for {participantName} to join the call …" : "Väntar på att {participantName} ansluter sig till samtalet ...",
-    "WebRTC is not supported in your browser :-/" : "WebRTC är inte kompatibelt med din webbläsare :-/",
-    "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
-    "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
-    "Share screen" : "Dela skärm",
-    "No Camera" : "Ingen kamera",
-    "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
-    "Error while promoting user to moderator" : "Kunde inte göra användaren till moderator",
-    "Error while demoting moderator" : "Kunde inte ta bort moderator",
-    "Error while removing user from room" : "Kunde inte ta bort användaren från rummet",
-    "Add participant …" : "Lägg till deltagare",
-    "Favorited" : "Favorit",
     "Your screen" : "Din skärm",
-    "{participantName}'s screen" : "{participantName}'s skärm",
-    "Guest's screen" : "Gästskärm",
-    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait." : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
-    "{email} tried to requested the password to access {file}" : "{email} försökte begära lösenordet för åtkomst till {file}",
-    "Someone tried to requested the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
-    "Limit app usage to groups." : "Begränsa appanvändning till grupper",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandon är en ny beta-funktion i Nextcloud Talk. Det låter dig köra skript på din Nextcloud-server. Du kan definiera dem med vårt kommandoradsgränssnitt. Ett exempel på ett kalkylatorskript finns i vår <a {attributes}>dokumentation ↗</a>.",
-    "Start calls" : "Starta samtal",
-    "Who can start a call?" : "Vem kan starta ett samtal?",
-    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
-    "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
-    "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
     "Contacts" : "Kontakter",
     "Contacts, groups and circles" : "Kontakter, grupper och cirklar",
     "Contacts and groups" : "Kontakter och grupper",
@@ -712,13 +644,27 @@ OC.L10N.register(
     "Loading contacts" : "Laddar kontakter",
     "Select participants" : "Välj deltagare",
     "Search conversations or contacts" : "Sök konversationer eller kontakter",
+    "[Unknown user name]" : "[Okänt användarnam]",
     "Search for more contacts" : "Sök efter fler kontakter",
     "Contacts loading" : "Laddar kontakter",
+    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
     "Add contacts" : "Lägg till kontakter",
     "Add contacts, groups or circles" : "Lägg till kontakter, grupper och cirklar",
     "Add contacts or groups" : "Lägg till kontakter eller grupper",
     "Add contacts or circles" : "Lägg till kontakter eller cirklar",
+    "Guests" : "Gäster",
+    "Webinar" : "Webinar",
+    "Projects" : "Projekt",
+    "Limit app usage to groups." : "Begränsa appanvändning till grupper",
+    "Start calls" : "Starta samtal",
+    "Who can start a call?" : "Vem kan starta ett samtal?",
+    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
+    "Please enter the password for this call" : "Vänligen ange lösenordet för detta samtal",
+    "Password required" : "Lösenord krävs",
+    "Cancel" : "Avbryt",
+    "Submit" : "Skicka",
     "Signaling server URL" : "Signalerar serverwebbadress",
+    "This conversation is read only" : "Denna konversation är skrivskyddad",
     "Default location for attachments" : "Standardplats för bilagor",
     "Select default location for attachments" : "Välj standardplats för bilagor",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal"
