@@ -113,7 +113,6 @@ OC.L10N.register(
     "Enable video" : "Bật Video",
     "Screensharing options" : "Tùy chọn chia sẻ màn hình",
     "Enable screensharing" : "Bật chia sẽ màn hình",
-    "Back" : "Quay lại",
     "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
     "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
@@ -131,6 +130,7 @@ OC.L10N.register(
     "Circles" : "Vòng kết nối",
     "Settings" : "Thiết lập",
     "Password protect" : "Mật khẩu bảo vệ",
+    "Back" : "Quay lại",
     "Close" : "Đóng",
     "Conversation name" : "Tên đàm thoại",
     "Reply" : "Trả l",
@@ -165,6 +165,7 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Thoát chế độ toàn màn hình (f)",
     "Fullscreen (f)" : "Toàn màn hình (f)",
     "Grid view" : "Xem dạng Lưới",
+    "Send" : "Gửi",
     "Start a conversation" : "Bắt đầu một cuộc Đàm thoại",
     "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
     "Default" : "Mặc định",
@@ -181,47 +182,15 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%sNói chuyện trên thiết bị di động của bạn ",
     "Android app" : "Ứng dụng Android",
     "iOS app" : "Ứng dụng IOS",
-    "{name} (public)" : "{name} (public)",
-    "New conversation …" : "Đàm thoại mới...",
+    "No other people in this call" : "Không có người nào trong cuộc gọi này",
+    "Your screen" : "Màn hình của bạn",
+    "Contacts" : "Liên hệ",
+    "[Unknown user name]" : "[Tên người dùng chưa biết]",
     "Projects" : "Dự án",
-    "Copy" : "Sao chép",
-    "Copied!" : "Đã sao chép!",
-    "Not supported!" : "Không hỗ trợ!",
-    "Press ⌘-C to copy." : "Bấm ⌘-C để sao chép.",
-    "Press Ctrl-C to copy." : "Bấm Ctrl-C để sao chép.",
     "Please enter the password for this call" : "Hãy nhập một mật khẩu cho cuộc gọi này",
     "Password required" : "Mật khẩu đã được yêu cầu",
     "Cancel" : "Hủy bỏ",
     "Submit" : "Gửi đi",
-    "Change password" : "Đổi mật khẩu",
-    "Set password" : "Đặt mật khẩu",
-    "Rename" : "Đổi tên",
-    "Link copied!" : "Liên kết đã được sao chép!",
-    "Conversation with {name}" : "Đàm thoại với {name}",
-    "Error occurred while setting password" : "Đã xảy ra lỗi khi đặt mật khẩu",
-    "No messages yet, start the conversation!" : "Chưa có tin nhắn, bắt đầu cuộc trò chuyện!",
-    "New message …" : "Thông điệp mới...",
-    "Send" : "Gửi",
-    "Share" : "Chia sẻ",
-    "[Unknown user name]" : "[Tên người dùng chưa biết]",
-    "Error occurred while sending message" : "Đã xảy ra lỗi khi gửi tin nhắn",
-    "Error while sharing" : "Lỗi khi chia sẻ",
-    "No other people in this call" : "Không có người nào trong cuộc gọi này",
-    "Waiting for {participantName} to join the call …" : "Đang chờ {participantName} tham gia cuộc gọi…",
-    "WebRTC is not supported in your browser :-/" : "WebRTC không được hỗ trợ trong trình duyệt của bạn :-/",
-    "Waiting for camera and microphone permissions" : "Đang chờ cấp quyền đối với máy ảnh và micrô",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "Vui lòng cung cấp cho trình duyệt quyền truy cập của bạn để sử dụng máy ảnh và micrô của bạn để sử dụng ứng dụng này.",
-    "Set your name in the chat window so other participants can identify you better." : "Đặt tên của bạn trong cửa sổ trò chuyện để những người tham gia khác có thể xác định bạn tốt hơn.",
-    "Share screen" : "Chia sẽ màn hình",
-    "No Camera" : "Không có Camera",
-    "Screensharing is not supported by your browser." : "Chia sẽ màn hình không được hỗ trợ bởi trình duyệt của bạn.",
-    "Add participant …" : "Thêm người tham gia …",
-    "Favorited" : "Được ưa thích",
-    "Your screen" : "Màn hình của bạn",
-    "{participantName}'s screen" : "Màn hình của {participantName}",
-    "Guest's screen" : "Màn hình Khách",
-    "Join conversations at any time, any where, on any device." : "Tham gia cuộc trò chuyện bất kỳ lúc nào, ở bất kỳ đâu, trên mọi thiết bị.",
-    "Contacts" : "Liên hệ",
     "Signaling server URL" : "URL máy chủ đăng ký"
 },
 "nplurals=1; plural=0;");
