@@ -24,6 +24,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Chat;
 
+use OC\Memcache\ArrayCache;
+use OC\Memcache\NullCache;
 use OCA\Talk\Events\ChatEvent;
 use OCA\Talk\Events\ChatParticipantEvent;
 use OCA\Talk\Participant;
@@ -33,7 +35,11 @@ use OCP\Comments\IComment;
 use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
 use OCP\EventDispatcher\IEventDispatcher;
+use OCP\ICache;
+use OCP\ICacheFactory;
+use OCP\IDBConnection;
 use OCP\IUser;
+use OCP\Notification\IManager as INotificationManager;
 
 /**
  * Basic polling chat manager.
@@ -57,18 +63,30 @@ class ChatManager {
 	private $commentsManager;
 	/** @var IEventDispatcher */
 	private $dispatcher;
+	/** @var IDBConnection */
+	private $connection;
+	/** @var INotificationManager */
+	private $notificationManager;
 	/** @var Notifier */
 	private $notifier;
 	/** @var ITimeFactory */
 	protected $timeFactory;
+	/** @var ICache */
+	protected $cache;
 
 	public function __construct(CommentsManager $commentsManager,
 								IEventDispatcher $dispatcher,
+								IDBConnection $connection,
+								INotificationManager $notificationManager,
 								Notifier $notifier,
+								ICacheFactory $cacheFactory,
 								ITimeFactory $timeFactory) {
 		$this->commentsManager = $commentsManager;
 		$this->dispatcher = $dispatcher;
+		$this->connection = $connection;
+		$this->notificationManager = $notificationManager;
 		$this->notifier = $notifier;
+		$this->cache = $cacheFactory->createDistributed('talk/lastmsgid');
 		$this->timeFactory = $timeFactory;
 	}
 
@@ -81,12 +99,16 @@ class ChatManager {
 	 * @param string $message
 	 * @param \DateTime $creationDateTime
 	 * @param bool $sendNotifications
+	 * @param string|null $referenceId
 	 * @return IComment
 	 */
-	public function addSystemMessage(Room $chat, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, bool $sendNotifications): IComment {
+	public function addSystemMessage(Room $chat, string $actorType, string $actorId, string $message, \DateTime $creationDateTime, bool $sendNotifications, ?string $referenceId = null): IComment {
 		$comment = $this->commentsManager->create($actorType, $actorId, 'chat', (string) $chat->getId());
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
+		if ($referenceId !== null) {
+			$comment->setReferenceId($referenceId);
+		}
 		$comment->setVerb('system');
 
 		$event = new ChatEvent($chat, $comment);
@@ -104,6 +126,7 @@ class ChatManager {
 			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
 		} catch (NotFoundException $e) {
 		}
+		$this->cache->remove($chat->getToken());
 
 		return $comment;
 	}
@@ -133,6 +156,7 @@ class ChatManager {
 			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
 		} catch (NotFoundException $e) {
 		}
+		$this->cache->remove($chat->getToken());
 
 		return $comment;
 	}
@@ -170,6 +194,7 @@ class ChatManager {
 		$event = new ChatParticipantEvent($chat, $comment, $participant);
 		$this->dispatcher->dispatch(self::EVENT_BEFORE_MESSAGE_SEND, $event);
 
+		$shouldFlush = $this->notificationManager->defer();
 		try {
 			$this->commentsManager->save($comment);
 
@@ -192,6 +217,10 @@ class ChatManager {
 			$this->dispatcher->dispatch(self::EVENT_AFTER_MESSAGE_SEND, $event);
 		} catch (NotFoundException $e) {
 		}
+		$this->cache->remove($chat->getToken());
+		if ($shouldFlush) {
+			$this->notificationManager->flush();
+		}
 
 		return $comment;
 	}
@@ -264,6 +293,82 @@ class ChatManager {
 		if ($user instanceof IUser) {
 			$this->notifier->markMentionNotificationsRead($chat, $user->getUID());
 		}
+
+		if ($this->cache instanceof NullCache
+			|| $this->cache instanceof ArrayCache) {
+			return $this->waitForNewMessagesWithDatabase($chat, $offset, $limit, $timeout, $includeLastKnown);
+		}
+
+		return $this->waitForNewMessagesWithCache($chat, $offset, $limit, $timeout, $includeLastKnown);
+	}
+
+	/**
+	 * Check the cache until we found new messages, or the timeout was reached
+	 *
+	 * @param Room $chat
+	 * @param int $offset
+	 * @param int $limit
+	 * @param int $timeout
+	 * @param bool $includeLastKnown
+	 * @return IComment[]
+	 */
+	protected function waitForNewMessagesWithCache(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown): array {
+		$elapsedTime = 0;
+
+		$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown);
+
+		while (empty($comments) && $elapsedTime < $timeout) {
+			$this->connection->close();
+			sleep(1);
+			$elapsedTime++;
+
+			$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown);
+		}
+
+		return $comments;
+	}
+
+	/**
+	 * Check the cache for the last message id or check the database for updates
+	 *
+	 * @param Room $chat
+	 * @param int $offset
+	 * @param int $limit
+	 * @param bool $includeLastKnown
+	 * @return IComment[]
+	 */
+	protected function checkCacheOrDatabase(Room $chat, int $offset, int $limit, bool $includeLastKnown): array {
+		$cachedId = $this->cache->get($chat->getToken());
+		if ($offset === $cachedId) {
+			// Cache hit, nothing new ¯\_(ツ)_/¯
+			return [];
+		}
+
+		// Load data from the database
+		$comments = $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+
+		if (empty($comments)) {
+			// We only write the cache when there were no new comments,
+			// otherwise it could happen that this is not the last message,
+			// but the last within $limit
+			$this->cache->set($chat->getToken(), $offset, 30);
+			return [];
+		}
+
+		return $comments;
+	}
+
+	/**
+	 * Check the database for new messages until there a new messages or we exceeded the timeout
+	 *
+	 * @param Room $chat
+	 * @param int $offset
+	 * @param int $limit
+	 * @param int $timeout
+	 * @param bool $includeLastKnown
+	 * @return array
+	 */
+	protected function waitForNewMessagesWithDatabase(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown): array {
 		$elapsedTime = 0;
 
 		$comments = $this->commentsManager->getForObjectSince('chat', (string) $chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
@@ -288,4 +393,18 @@ class ChatManager {
 
 		$this->notifier->removePendingNotificationsForRoom($chat);
 	}
+
+	/**
+	 * Search for comments with a given content
+	 *
+	 * @param string $search content to search for
+	 * @param array $objectIds Limit the search by object ids
+	 * @param string $verb Limit the verb of the comment
+	 * @param int $offset
+	 * @param int $limit
+	 * @return IComment[]
+	 */
+	public function searchForObjects(string $search,  array $objectIds, string $verb = '', int $offset = 0, int $limit = 50): array {
+		return $this->commentsManager->searchForObjects($search, 'chat', $objectIds, $verb, $offset, $limit);
+	}
 }
