@@ -265,6 +265,8 @@ class RoomController extends AEnvironmentAwareController {
 			'unreadMention' => false,
 			'isFavorite' => false,
 			'notificationLevel' => Participant::NOTIFY_NEVER,
+			'lobbyState' => Webinary::LOBBY_NONE,
+			'lobbyTimer' => 0,
 			'lastPing' => 0,
 			'sessionId' => '0',
 			'participants' => [],
@@ -441,6 +443,8 @@ class RoomController extends AEnvironmentAwareController {
 			'canLeaveConversation' => false,
 			'canDeleteConversation' => false,
 			'notificationLevel' => Participant::NOTIFY_NEVER,
+			'lobbyState' => Webinary::LOBBY_NONE,
+			'lobbyTimer' => 0,
 			'lastPing' => 0,
 			'sessionId' => '0',
 			'guestList' => '',
@@ -1225,8 +1229,8 @@ class RoomController extends AEnvironmentAwareController {
 		}
 
 		if ($previousSession instanceof Participant && $previousSession->getSessionId() !== '0') {
-			// Previous session was active
-			if ($force === false) {
+			if ($force === false && $previousSession->getInCallFlags() !== Participant::FLAG_DISCONNECTED) {
+				// Previous session was active in the call, show a warning
 				return new DataResponse([
 					'sessionId' => $previousSession->getSessionId(),
 					'inCall' => $previousSession->getInCallFlags(),
